@@ -149,6 +149,36 @@ void sCommand_sweep_runtime_info(sCommand* self)
     }
 }
 
+void sStatment_sweep_runtime_info(sStatment* self)
+{
+    int j;
+    for(j=0; j<self->mCommandsNum; j++) {
+        sCommand* command = self->mCommands + j;
+        
+        int i;
+        for(i=0; i<command->mArgsNumRuntime; i++) {
+            FREE(command->mArgsRuntime[i]);
+        }
+        command->mArgsNumRuntime = 0;
+
+        for(i=0; i<XYZSH_OPTION_MAX; i++) {
+            if(command->mOptions[i].mKey) { FREE(command->mOptions[i].mKey); }
+            if(command->mOptions[i].mArg) { FREE(command->mOptions[i].mArg); }
+        }
+
+        memset(command->mOptions, 0, sizeof(option_hash_it)*XYZSH_OPTION_MAX);
+
+        if(command->mRedirectsFileNamesRuntime) {
+            for(i=0; i<command->mRedirectsNum; i++) {
+                FREE(command->mRedirectsFileNamesRuntime[i]);
+            }
+            FREE(command->mRedirectsFileNamesRuntime);
+
+            command->mRedirectsFileNamesRuntime = NULL;
+        }
+    }
+}
+
 void sCommand_add_redirect_to_command(sCommand* self, MANAGED char* name, int redirect)
 {
     if(self->mRedirectsNum >= self->mRedirectsSize) {
@@ -1130,7 +1160,7 @@ static BOOL expand_env_to_command(ALLOC char** result, char* str, sCommand* comm
 
                 if(!run(env->mBlock, nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject))
                 {
-                    err_msg("run time error", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                     runinfo->mRCode = rcode;
                     FREE(buf.mBuf);
                     return FALSE;
