@@ -786,7 +786,7 @@ BOOL cmd_condition_re(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 #if defined(HAVE_MIGEMO_H)
 #include <migemo.h>
 
-migemo* gMigemo;
+static migemo* gMigemo;
 static regex_t* gReg;
 
 void migemo_init()
