@@ -714,8 +714,6 @@ BOOL cmd_ref(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         /// type
         if(sCommand_option_item(command, "-type")) {
-            sObject* object = runinfo->mCurrentObject;
-
             int i;
             int max = vector_count(SFD(nextin).fdbuf.mLines);
             for(i=0; i<max; i++) {
@@ -753,7 +751,13 @@ BOOL cmd_ref(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
         else {
             if(command->mArgsNumRuntime > 1) {
-                sObject* object = runinfo->mCurrentObject;
+                sObject* object;
+                if(sCommand_option_item(command, "-local")) {
+                    object = SFUN(runinfo->mRunningObject).mLocalObjects;
+                }
+                else {
+                    object = runinfo->mCurrentObject;
+                }
 
                 int i;
                 int max = vector_count(SFD(nextin).fdbuf.mLines);
