@@ -712,6 +712,7 @@ void xyzsh_opt_c(char* cmd, char** argv, int argc);
 void xyzsh_readline_interface(char* cmdline, int cursor, char** argv, int argc);
 
 void fd_split(sObject* self, enum eLineField lf);
+BOOL fd_guess_lf(sObject* self, enum eLineField* lf);
 
 void err_msg(char* msg, char* sname, int line, char* command);
 void err_msg_adding(char* msg, char* sname, int line, char* command);
@@ -791,6 +792,7 @@ int get_onig_regex(regex_t** reg, sCommand* command, char* regex);
 extern sObject* gPrompt;
 
 extern sObject* gGlobalPipe;
+extern sObject* gPipes;
 
 int readline_signal();
 void clear_matching_info_variable();
@@ -814,6 +816,8 @@ void readline_write_history();
 void readline_read_history();
 void xyzsh_read_rc_core(char* path);
 
+#define XYZSH_OBJECTS_IN_PIPE_MAX 128
+
 extern sObject* gStackFrames;
 
 #if defined(HAVE_MIGEMO_H)
